==> sqlmesh-0.224.1.dev22.tar.gz: sqlmesh-0.224.1.dev22/web/common/src/components/Lineage/node/NodePort.tsx <==
import { useNodeConnections, useUpdateNodeInternals } from '@xyflow/react'
import React from 'react'

import { cn } from '@/utils'
import { type NodeId, type PortId } from '../utils'
import { NodeHandles } from './NodeHandles'

export const NodePort = React.memo(function NodePort<
  TPortId extends string = PortId,
  TNodeID extends string = NodeId,
>({
  id,
  nodeId,
  className,
  children,
}: {
  id: TPortId
  nodeId: TNodeID
  className?: string
  children: React.ReactNode
}) {
  const updateNodeInternals = useUpdateNodeInternals()

  const sources = useNodeConnections({
    id: nodeId,
    handleType: 'source',
    handleId: id,
  })
  const targets = useNodeConnections({
    id: nodeId,
    handleType: 'target',
    handleId: id,
  })

  const leftId = targets.length > 0 ? id : undefined
  const rightId = sources.length > 0 ? id : undefined

  React.useEffect(() => {
    if (leftId || rightId) {
      updateNodeInternals(nodeId)
    }
  }, [updateNodeInternals, nodeId, leftId, rightId])

  return (
    <NodeHandles
      data-component="NodePort"
      leftIcon={
        <span className="flex-shrink-0 p-1.5 rounded-full bg-lineage-node-port-handle-target"></span>
      }
      rightIcon={
        <span className="flex-shrink-0 p-1.5 rounded-full bg-lineage-node-port-handle-source"></span>
      }
      leftId={leftId}
      rightId={rightId}
      className={cn(
        'relative overflow-visible group p-0 bg-lineage-node-port-background h-auto',
        className,
      )}
      handleClassName="absolute"
    >
      {children}
    </NodeHandles>
  )
})

==> sqlmesh-0.225.1.dev6.tar.gz: sqlmesh-0.225.1.dev6/web/common/src/components/Lineage/node/NodePort.tsx <==
import { useNodeConnections, useUpdateNodeInternals } from '@xyflow/react'
import React from 'react'

import { cn } from '@/utils'
import { type NodeId, type PortHandleId } from '../utils'
import { NodeHandles } from './NodeHandles'

export function NodePort<
  TPortId extends string = PortHandleId,
  TNodeID extends string = NodeId,
  TLeftPortHandleId extends string = PortHandleId,
  TRightPortHandleId extends string = PortHandleId,
>({
  id,
  nodeId,
  className,
  children,
}: {
  id: TPortId
  nodeId: TNodeID
  className?: string
  children: React.ReactNode
}) {
  const updateNodeInternals = useUpdateNodeInternals()

  const sources = useNodeConnections({
    id: nodeId,
    handleType: 'source',
    handleId: id,
  })
  const targets = useNodeConnections({
    id: nodeId,
    handleType: 'target',
    handleId: id,
  })

  const isLeftHandleId = (id: TPortId): id is TPortId & TLeftPortHandleId => {
    return id && targets.length > 0
  }

  const isRightHandleId = (id: TPortId): id is TPortId & TRightPortHandleId => {
    return id && sources.length > 0
  }

  const leftId = isLeftHandleId(id) ? id : undefined
  const rightId = isRightHandleId(id) ? id : undefined

  React.useEffect(() => {
    if (leftId || rightId) {
      updateNodeInternals(nodeId)
    }
  }, [updateNodeInternals, nodeId, leftId, rightId])

  return (
    <NodeHandles<TLeftPortHandleId, TRightPortHandleId>
      data-component="NodePort"
      leftIcon={
        <span className="flex-shrink-0 p-1.5 rounded-full bg-lineage-node-port-handle-target"></span>
      }
      rightIcon={
        <span className="flex-shrink-0 p-1.5 rounded-full bg-lineage-node-port-handle-source"></span>
      }
      leftId={leftId}
      rightId={rightId}
      className={cn(
        'relative overflow-visible group bg-lineage-node-port-background h-auto',
        className,
      )}
      handleClassName="absolute"
    >
      {children}
    </NodeHandles>
  )
}
